@@ -405,6 +405,7 @@ function DeletePrimitives(reprname)
   for (let i = 0; i < stage.compList.length; i++)
     if (stage.compList[i].reprList.length > 0 && stage.compList[i].reprList[0].name == reprname) {
       let thiscomp = stage.compList[i];
+      thiscomp.removeAllAnnotations();
       thiscomp.removeRepresentation(thisrepr);
       stage.removeComponent(thiscomp);
       wasremoved = true;
@@ -458,7 +459,7 @@ function CameraZoom(t, deltaX, deltaY) {
   if (Number.isInteger(deltaY))
     dy = deltaY;
   let z = stage.viewer.camera.zoom;
-  z -= (dx+dy) / 4.0;
+  z -= (dx + dy) * stage.trackballControls.rotateSpeed; // which is adjusted by SetMouseSpeed message
   if (z > 0.0) {// use positive zoom values to avoid mirroring the stage
     stage.viewer.camera.zoom = z;
     stage.viewer.requestRender();
@@ -1965,7 +1966,9 @@ function GetReflectionsInFrustumFromBuffer(buffer) {
   if (buffer.parameters.opacity < 0.3) // use the same threshold as when tooltips won't show
     return [hkls_infrustums, rotid_infrustum];
 
-  for (let i = 0; i < buffer.picking.cartpos.length; i++) {
+  for (let i = 0; i < buffer.picking.cartpos.length; i++)
+  {
+    let radius = buffer.geometry.attributes.radius.array[i];
     let x = buffer.picking.cartpos[i][0];
     let y = buffer.picking.cartpos[i][1];
     let z = buffer.picking.cartpos[i][2];
@@ -1974,7 +1977,8 @@ function GetReflectionsInFrustumFromBuffer(buffer) {
     let currenthklpos = hklpos.applyMatrix4(m);
     let childZ = currenthklpos.z - stage.viewer.camera.position.z;
     let infrustum = false;
-    if (childZ <= stage.viewer.parameters.clipFar && childZ >= stage.viewer.parameters.clipNear) {
+    if ((childZ + radius) <stage.viewer.parameters.clipFar && (childZ - radius) > stage.viewer.parameters.clipNear)
+    {
       infrustum = true;
       let hklid = buffer.picking.ids[i + 1];
       let rotid = buffer.picking.ids[0];
@@ -2026,7 +2030,11 @@ function MakePlusMinusButtons() {
     onclick: function () {
       WebsockSendMsg('MoveClipPlanesUp');
     },
-  }, { bottom: pmbottom.toString() + "px", left: pmleft.toString() + "px", width: btnwidth.toString + "px", position: "absolute" }, fontsize);
+  },
+    {
+    bottom: pmbottom.toString() + "px", left: pmleft.toString() + "px",
+        width: btnwidth.toString + "px", position: "absolute", fontWeight: "700" // bold font
+    }, fontsize);
   addElement(PlusBtn);
 
   let left2 = btnwidth + pmleft + 20;
@@ -2037,7 +2045,10 @@ function MakePlusMinusButtons() {
     onclick: function () {
       WebsockSendMsg('MoveClipPlanesDown');
     },
-  }, { bottom: pmbottom.toString() + "px", left: left2.toString() + "px", width: btnwidth.toString + "px", position: "absolute" }, fontsize);
+  }, {
+      bottom: pmbottom.toString() + "px", left: left2.toString() + "px",
+      width: btnwidth.toString + "px", position: "absolute", fontWeight: "700" // bold font
+  }, fontsize);
   addElement(MinusBtn);
 };
 
