@@ -52,6 +52,7 @@ default_datatypes = ['map_coefficients', 'miller_array', 'model', 'ncs_spec',
 # custom options for processing data
 # generally the format is <datatype>_<custom option>
 data_manager_options = [
+  'miller_array_skip_merge',       # does not merge Miller arrays
   'model_skip_expand_with_mtrix',  # does not expand a model using MTRIX
   'model_skip_ss_annotations',     # ignore secondary structure annotations
   ]
@@ -162,6 +163,11 @@ def DataManager(datatypes=None, phil=None, custom_options=None, logger=None):
     mixin_classes.append(
       getattr(sys.modules['iotbx.data_manager.common'], 'map_model_mixins'))
 
+  if 'model' in datatypes and 'miller_array' in datatypes:
+    importlib.import_module('.common', package='iotbx.data_manager')
+    mixin_classes.append(
+      getattr(sys.modules['iotbx.data_manager.common'], 'fmodel_mixins'))
+
   # construct new class and return instance
   classes = tuple(manager_classes + parent_classes + mixin_classes)
   data_manager_class = type('DataManager', classes, dict())
